==> deepin-grand-search-5.3.2-2.src.tar.gz: dde-grand-search-5.3.2/translations/dde-grand-search_zh_TW.ts <==
<?xml version="1.0" ?><!DOCTYPE TS><TS version="2.1" language="zh_TW">
<context>
    <name>AudioPreviewPlugin</name>
    <message>
        <location filename="../src/preview-plugin/audio-preview/audiopreviewplugin.cpp" line="71"/>
        <source>Artist:</source>
        <translation>演唱者：</translation>
    </message>
    <message>
        <location filename="../src/preview-plugin/audio-preview/audiopreviewplugin.cpp" line="83"/>
        <source>Album:</source>
        <translation>專輯名稱：</translation>
    </message>
    <message>
        <location filename="../src/preview-plugin/audio-preview/audiopreviewplugin.cpp" line="108"/>
        <source>Duration:</source>
        <translation>影片長度：</translation>
    </message>
    <message>
        <location filename="../src/preview-plugin/audio-preview/audiopreviewplugin.cpp" line="123"/>
        <source>Type:</source>
        <translation>類型：</translation>
    </message>
    <message>
        <location filename="../src/preview-plugin/audio-preview/audiopreviewplugin.cpp" line="135"/>
        <source>Location:</source>
        <translation>位置：</translation>
    </message>
    <message>
        <location filename="../src/preview-plugin/audio-preview/audiopreviewplugin.cpp" line="149"/>
        <source>Time modified:</source>
        <translation>修改時間：</translation>
    </message>
</context>
<context>
    <name>BestMatchWidget</name>
    <message>
        <location filename="../src/grand-search/gui/searchconfig/bestmatchwidget.cpp" line="38"/>
        <source>Best match</source>
        <translation>最佳匹配</translation>
    </message>
</context>
<context>
    <name>CustomWidget</name>
    <message>
        <location filename="../src/grand-search/gui/searchconfig/customwidget.cpp" line="42"/>
        <source>Custom search</source>
        <translation>個性化</translation>
    </message>
</context>
<context>
    <name>DdeGrandSearchDockPlugin</name>
    <message>
        <location filename="../src/grand-search-dock-plugin/ddegrandsearchdockplugin.cpp" line="57"/>
        <location filename="../src/grand-search-dock-plugin/ddegrandsearchdockplugin.cpp" line="100"/>
        <source>Grand Search</source>
        <translation>全域搜尋</translation>
    </message>
    <message>
        <location filename="../src/grand-search-dock-plugin/ddegrandsearchdockplugin.cpp" line="163"/>
        <source>Search settings</source>
        <translation>搜尋設定</translation>
    </message>
</context>
<context>
    <name>EntranceWidget</name>
    <message>
        <location filename="../src/grand-search/gui/entrance/entrancewidget.cpp" line="241"/>
        <source>Search</source>
        <translation>搜尋</translation>
    </message>
    <message>
        <location filename="../src/grand-search/gui/entrance/entrancewidget.cpp" line="242"/>
        <source>What would you like to search for?</source>
        <translation>搜尋想要尋找的內容</translation>
    </message>
</context>
<context>
    <name>EntranceWidgetPrivate</name>
    <message>
        <location filename="../src/grand-search/gui/entrance/entrancewidget.cpp" line="94"/>
        <source>Cut</source>
        <translation>剪下</translation>
    </message>
    <message>
        <location filename="../src/grand-search/gui/entrance/entrancewidget.cpp" line="98"/>
        <source>Copy</source>
        <translation>複製</translation>
    </message>
    <message>
        <location filename="../src/grand-search/gui/entrance/entrancewidget.cpp" line="102"/>
        <source>Paste</source>
        <translation>貼上</translation>
    </message>
</context>
<context>
    <name>GeneralPreviewPlugin</name>
    <message>
        <location filename="../src/grand-search/gui/exhibition/preview/generalpreviewplugin.cpp" line="208"/>
        <source>Location:</source>
        <translation>位置：</translation>
    </message>
    <message>
        <location filename="../src/grand-search/gui/exhibition/preview/generalpreviewplugin.cpp" line="219"/>
        <source>Time modified:</source>
        <translation>修改時間：</translation>
    </message>
</context>
<context>
    <name>GeneralToolBar</name>
    <message>
        <location filename="../src/grand-search/gui/exhibition/preview/generalwidget/generaltoolbar.cpp" line="85"/>
        <source>Open</source>
        <translation>開啟</translation>
    </message>
    <message>
        <location filename="../src/grand-search/gui/exhibition/preview/generalwidget/generaltoolbar.cpp" line="90"/>
        <source>Open Path</source>
        <translation>打開路徑</translation>
    </message>
    <message>
        <location filename="../src/grand-search/gui/exhibition/preview/generalwidget/generaltoolbar.cpp" line="95"/>
        <source>Copy Path</source>
        <translation>複製路徑</translation>
    </message>
</context>
<context>
    <name>GroupWidget</name>
    <message>
        <location filename="../src/grand-search/gui/exhibition/matchresult/groupwidget.cpp" line="260"/>
        <source>More</source>
        <translation>查看更多</translation>
    </message>
</context>
<context>
    <name>ImagePreviewPlugin</name>
    <message>
        <location filename="../src/preview-plugin/image-preview/imagepreviewplugin.cpp" line="67"/>
        <source>Dimensions:</source>
        <translation>尺寸：</translation>
    </message>
    <message>
        <location filename="../src/preview-plugin/image-preview/imagepreviewplugin.cpp" line="83"/>
        <source>Type:</source>
        <translation>類型：</translation>
    </message>
    <message>
        <location filename="../src/preview-plugin/image-preview/imagepreviewplugin.cpp" line="98"/>
        <source>Size:</source>
        <translation>大小：</translation>
    </message>
    <message>
        <location filename="../src/preview-plugin/image-preview/imagepreviewplugin.cpp" line="110"/>
        <source>Location:</source>
        <translation>位置：</translation>
    </message>
    <message>
        <location filename="../src/preview-plugin/image-preview/imagepreviewplugin.cpp" line="124"/>
        <source>Time modified:</source>
        <translation>修改時間：</translation>
    </message>
</context>
<context>
    <name>MainWindow</name>
    <message>
        <location filename="../src/grand-search/gui/mainwindow.cpp" line="224"/>
        <source>No search results</source>
        <translation>無搜尋結果</translation>
    </message>
</context>
<context>
    <name>PlanWidget</name>
    <message>
        <location filename="../src/grand-search/gui/searchconfig/planwidget.cpp" line="43"/>
        <source>Search experience program</source>
        <translation>搜尋體驗計劃</translation>
    </message>
    <message>
        <location filename="../src/grand-search/gui/searchconfig/planwidget.cpp" line="51"/>
        <source>Join search experience program</source>
        <translation>加入搜尋體驗計劃</translation>
    </message>
    <message>
        <location filename="../src/grand-search/gui/searchconfig/planwidget.cpp" line="64"/>
        <source>Joining the search experience program means that you grant and authorize us to collect the information of your device and system, file icons, content and properties, applications and their configurations. If you refuse our collection and use of the aforementioned information, do not join the program.</source>
        <translation>開啟搜尋體驗計劃，視為您授權我們收集與您的裝置、系統、文件圖示、部分文件內容、文件屬性、應用軟體及配置等訊息，您可以關閉搜尋體驗計劃，以拒絕我們對前述訊息的收集與使用。</translation>
    </message>
    <message>
        <location filename="../src/grand-search/gui/searchconfig/planwidget.cpp" line="73"/>
        <source>To know more about the management of your data, please refer to the UnionTech Software Privacy Policy (</source>
        <translation>了解對資料的管理與使用方式，請參考統信軟體隱私政策（</translation>
    </message>
    <message>
        <location filename="../src/grand-search/gui/searchconfig/planwidget.cpp" line="75"/>
        <source>https://www.uniontech.com/agreement/privacy-en</source>
        <translation>https://www.uniontech.com/agreement/privacy-tw</translation>
    </message>
    <message>
        <location filename="../src/grand-search/gui/searchconfig/planwidget.cpp" line="76"/>
        <source>https://www.deepin.org/en/agreement/privacy/</source>
        <translation>https://www.deepin.org/zh/agreement/privacy/</translation>
    </message>
    <message>
        <location filename="../src/grand-search/gui/searchconfig/planwidget.cpp" line="78"/>
        <source>).</source>
        <translation>）。</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <location filename="../src/grand-search/gui/datadefine.h" line="41"/>
        <source>Best match</source>
        <translation>最佳匹配</translation>
    </message>
    <message>
        <location filename="../src/grand-search/gui/datadefine.h" line="42"/>
        <source>Applications</source>
        <translation>應用</translation>
    </message>
    <message>
        <location filename="../src/grand-search/gui/datadefine.h" line="43"/>
        <source>Settings</source>
        <translation>設定</translation>
    </message>
    <message>
        <location filename="../src/grand-search/gui/datadefine.h" line="44"/>
        <source>Videos</source>
        <translation>影片</translation>
    </message>
    <message>
        <location filename="../src/grand-search/gui/datadefine.h" line="45"/>
        <source>Music</source>
        <translation>音樂</translation>
    </message>
    <message>
        <location filename="../src/grand-search/gui/datadefine.h" line="46"/>
        <source>Pictures</source>
        <translation>圖片</translation>
    </message>
    <message>
        <location filename="../src/grand-search/gui/datadefine.h" line="47"/>
        <source>Documents</source>
        <translation>文件</translation>
    </message>
    <message>
        <location filename="../src/grand-search/gui/datadefine.h" line="48"/>
        <source>Folders</source>
        <translation>資料夾</translation>
    </message>
    <message>
        <location filename="../src/grand-search/gui/datadefine.h" line="49"/>
        <source>Files</source>
        <translation>文件</translation>
    </message>
    <message>
        <location filename="../src/grand-search/gui/datadefine.h" line="50"/>
        <source>Web</source>
        <translation>Web搜尋</translation>
    </message>
    <message>
        <location filename="../src/preview-plugin/video-preview/videopreviewplugin.cpp" line="38"/>
        <source>Dimensions:</source>
        <translation>尺寸：</translation>
    </message>
    <message>
        <location filename="../src/preview-plugin/video-preview/videopreviewplugin.cpp" line="39"/>
        <source>Type:</source>
        <translation>類型：</translation>
    </message>
    <message>
        <location filename="../src/preview-plugin/video-preview/videopreviewplugin.cpp" line="40"/>
        <source>Size:</source>
        <translation>大小：</translation>
    </message>
    <message>
        <location filename="../src/preview-plugin/video-preview/videopreviewplugin.cpp" line="41"/>
        <source>Duration:</source>
        <translation>影片長度：</translation>
    </message>
    <message>
        <location filename="../src/preview-plugin/video-preview/videopreviewplugin.cpp" line="42"/>
        <source>Location:</source>
        <translation>位置：</translation>
    </message>
    <message>
        <location filename="../src/preview-plugin/video-preview/videopreviewplugin.cpp" line="43"/>
        <source>Time modified:</source>
        <translation>修改時間：</translation>
    </message>
    <message>
        <location filename="../src/grand-search-daemon/searcher/file/filesearchutils.cpp" line="215"/>
        <source>modified</source>
        <translation>修改</translation>
    </message>
</context>
<context>
    <name>ScopeWidget</name>
    <message>
        <location filename="../src/grand-search/gui/searchconfig/scopewidget.cpp" line="44"/>
        <source>Search contents</source>
        <translation>搜尋範圍</translation>
    </message>
</context>
<context>
    <name>SearchEngineWidget</name>
    <message>
        <location filename="../src/grand-search/gui/searchconfig/searchenginewidget.cpp" line="48"/>
        <source>Default search engine</source>
        <translation>預設搜尋引擎</translation>
    </message>
    <message>
        <location filename="../src/grand-search/gui/searchconfig/searchenginewidget.cpp" line="56"/>
        <source>Search for keywords by the default search engine.</source>
        <translation>透過搜尋關鍵字，可跳轉到的預設搜尋引擎</translation>
    </message>
    <message>
        <location filename="../src/grand-search/gui/searchconfig/searchenginewidget.cpp" line="72"/>
        <source>Default search engine is</source>
        <translation>預設搜尋引擎為</translation>
    </message>
    <message>
        <location filename="../src/grand-search/gui/searchconfig/searchenginewidget.cpp" line="81"/>
        <source>Google</source>
        <translation>Google</translation>
    </message>
    <message>
        <location filename="../src/grand-search/gui/searchconfig/searchenginewidget.cpp" line="82"/>
        <source>Baidu</source>
        <translation>百度</translation>
    </message>
    <message>
        <location filename="../src/grand-search/gui/searchconfig/searchenginewidget.cpp" line="83"/>
        <source>Bing</source>
        <translation>必應</translation>
    </message>
    <message>
        <location filename="../src/grand-search/gui/searchconfig/searchenginewidget.cpp" line="84"/>
        <source>Yahoo</source>
        <translation>雅虎</translation>
    </message>
    <message>
        <location filename="../src/grand-search/gui/searchconfig/searchenginewidget.cpp" line="85"/>
        <source>360</source>
        <translation>360</translation>
    </message>
    <message>
        <location filename="../src/grand-search/gui/searchconfig/searchenginewidget.cpp" line="86"/>
        <source>Sogou</source>
        <translation>搜狗</translation>
    </message>
</context>
<context>
    <name>StaticTextWorker</name>
    <message>
        <location filename="../src/grand-search-daemon/searcher/web/statictextworker.cpp" line="67"/>
        <source>Search for &quot;%1&quot;</source>
        <translation>透過瀏覽器搜尋“%1”</translation>
    </message>
</context>
<context>
    <name>TailerWidget</name>
    <message>
        <location filename="../src/grand-search/gui/searchconfig/tailerwidget.cpp" line="33"/>
        <source>Tailer settings</source>
        <translation>拖尾設定</translation>
    </message>
    <message>
        <location filename="../src/grand-search/gui/searchconfig/tailerwidget.cpp" line="43"/>
        <source>It is displayed at the end of search results for better identification and distinction of items with duplicate names.</source>
        <translation>搜尋結果尾部顯示，用於輔助識別搜尋結果或區分重名項。</translation>
    </message>
    <message>
        <location filename="../src/grand-search/gui/searchconfig/tailerwidget.cpp" line="56"/>
        <source>Parent directory</source>
        <translation>上級目錄</translation>
    </message>
    <message>
        <location filename="../src/grand-search/gui/searchconfig/tailerwidget.cpp" line="58"/>
        <source>Time modified</source>
        <translation>最近修改時間</translation>
    </message>
</context>
</TS>

==> deepin-grand-search-5.4.5-3.src.tar.gz: dde-grand-search-5.4.5/translations/dde-grand-search_zh_TW.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="zh_TW">
<context>
    <name>GrandSearch::BestMatchWidget</name>
    <message>
        <location filename="../src/grand-search/gui/searchconfig/bestmatchwidget.cpp" line="39"/>
        <source>Best match</source>
        <translation>最佳匹配</translation>
    </message>
</context>
<context>
    <name>GrandSearch::BlackListWidget</name>
    <message>
        <location filename="../src/grand-search/gui/searchconfig/blacklistwidget.cpp" line="43"/>
        <source>Excluded path</source>
        <translation>路徑黑名單</translation>
    </message>
    <message>
        <location filename="../src/grand-search/gui/searchconfig/blacklistwidget.cpp" line="54"/>
        <source>Add paths to the exclusion list to prevent searching in them.</source>
        <translation>可將不希望被搜尋到的路徑添加至黑名單中。</translation>
    </message>
</context>
<context>
    <name>GrandSearch::CustomWidget</name>
    <message>
        <location filename="../src/grand-search/gui/searchconfig/customwidget.cpp" line="42"/>
        <source>Custom search</source>
        <translation>個性化</translation>
    </message>
</context>
<context>
    <name>GrandSearch::DdeGrandSearchDockPlugin</name>
    <message>
        <location filename="../src/grand-search-dock-plugin/ddegrandsearchdockplugin.cpp" line="58"/>
        <location filename="../src/grand-search-dock-plugin/ddegrandsearchdockplugin.cpp" line="101"/>
        <source>Grand Search</source>
        <translation>全域搜尋</translation>
    </message>
    <message>
        <location filename="../src/grand-search-dock-plugin/ddegrandsearchdockplugin.cpp" line="164"/>
        <source>Search settings</source>
        <translation>搜尋設定</translation>
    </message>
</context>
<context>
    <name>GrandSearch::DeleteDialog</name>
    <message>
        <location filename="../src/grand-search/gui/searchconfig/blacklistview/deletedialog.cpp" line="31"/>
        <source>Do you want to remove the path from the exclusion list?</source>
        <translation>是否從路徑黑名單中移出選中路徑？</translation>
    </message>
    <message>
        <location filename="../src/grand-search/gui/searchconfig/blacklistview/deletedialog.cpp" line="37"/>
        <source>Cancel</source>
        <comment>button</comment>
        <translation>取 消</translation>
    </message>
    <message>
        <location filename="../src/grand-search/gui/searchconfig/blacklistview/deletedialog.cpp" line="45"/>
        <source>Confirm</source>
        <comment>button</comment>
        <translation>確 定</translation>
    </message>
</context>
<context>
    <name>GrandSearch::EntranceWidget</name>
    <message>
        <location filename="../src/grand-search/gui/entrance/entrancewidget.cpp" line="241"/>
        <source>Search</source>
        <translation>搜尋</translation>
    </message>
    <message>
        <location filename="../src/grand-search/gui/entrance/entrancewidget.cpp" line="242"/>
        <source>What would you like to search for?</source>
        <translation>搜尋想要尋找的內容</translation>
    </message>
</context>
<context>
    <name>GrandSearch::EntranceWidgetPrivate</name>
    <message>
        <location filename="../src/grand-search/gui/entrance/entrancewidget.cpp" line="94"/>
        <source>Cut</source>
        <translation>剪下</translation>
    </message>
    <message>
        <location filename="../src/grand-search/gui/entrance/entrancewidget.cpp" line="98"/>
        <source>Copy</source>
        <translation>複製</translation>
    </message>
    <message>
        <location filename="../src/grand-search/gui/entrance/entrancewidget.cpp" line="102"/>
        <source>Paste</source>
        <translation>貼上</translation>
    </message>
</context>
<context>
    <name>GrandSearch::GeneralPreviewPlugin</name>
    <message>
        <location filename="../src/grand-search/gui/exhibition/preview/generalpreviewplugin.cpp" line="208"/>
        <source>Location:</source>
        <translation>位置：</translation>
    </message>
    <message>
        <location filename="../src/grand-search/gui/exhibition/preview/generalpreviewplugin.cpp" line="219"/>
        <source>Time modified:</source>
        <translation>修改時間：</translation>
    </message>
</context>
<context>
    <name>GrandSearch::GeneralToolBar</name>
    <message>
        <location filename="../src/grand-search/gui/exhibition/preview/generalwidget/generaltoolbar.cpp" line="86"/>
        <source>Open</source>
        <translation>打開</translation>
    </message>
    <message>
        <location filename="../src/grand-search/gui/exhibition/preview/generalwidget/generaltoolbar.cpp" line="91"/>
        <source>Open Path</source>
        <translation>打開路徑</translation>
    </message>
    <message>
        <location filename="../src/grand-search/gui/exhibition/preview/generalwidget/generaltoolbar.cpp" line="96"/>
        <source>Copy Path</source>
        <translation>複製路徑</translation>
    </message>
</context>
<context>
    <name>GrandSearch::GroupWidget</name>
    <message>
        <location filename="../src/grand-search/gui/exhibition/matchresult/groupwidget.cpp" line="261"/>
        <source>More</source>
        <translation>更多</translation>
    </message>
</context>
<context>
    <name>GrandSearch::IndexWidget</name>
    <message>
        <location filename="../src/grand-search/gui/searchconfig/indexwidget.cpp" line="39"/>
        <source>Index</source>
        <translation>索引</translation>
    </message>
</context>
<context>
    <name>GrandSearch::MainWindow</name>
    <message>
        <location filename="../src/grand-search/gui/mainwindow.cpp" line="224"/>
        <source>No search results</source>
        <translation>找不到結果</translation>
    </message>
</context>
<context>
    <name>GrandSearch::PlanWidget</name>
    <message>
        <location filename="../src/grand-search/gui/searchconfig/planwidget.cpp" line="43"/>
        <source>Search experience program</source>
        <translation>搜尋體驗計劃</translation>
    </message>
    <message>
        <location filename="../src/grand-search/gui/searchconfig/planwidget.cpp" line="51"/>
        <source>Join search experience program</source>
        <translation>加入搜尋體驗計劃</translation>
    </message>
    <message>
        <location filename="../src/grand-search/gui/searchconfig/planwidget.cpp" line="64"/>
        <source>Joining the search experience program means that you grant and authorize us to collect the information of your device and system, file icons, content and properties, applications and their configurations. If you refuse our collection and use of the aforementioned information, do not join the program.</source>
        <translation>開啟搜尋體驗計劃，視為您授權我們收集與您的裝置、系統、文件圖示、部分文件內容、文件屬性、應用軟體及配置等訊息，您可以關閉搜尋體驗計劃，以拒絕我們對前述訊息的收集與使用。</translation>
    </message>
    <message>
        <location filename="../src/grand-search/gui/searchconfig/planwidget.cpp" line="73"/>
        <source>To know more about the management of your data, please refer to the UnionTech Software Privacy Policy (</source>
        <translation>了解對資料的管理與使用方式，請參考統信軟體隱私政策（</translation>
    </message>
    <message>
        <location filename="../src/grand-search/gui/searchconfig/planwidget.cpp" line="75"/>
        <source>https://www.uniontech.com/agreement/privacy-en</source>
        <translation>https://www.uniontech.com/agreement/privacy-tw</translation>
    </message>
    <message>
        <location filename="../src/grand-search/gui/searchconfig/planwidget.cpp" line="76"/>
        <source>https://www.deepin.org/en/agreement/privacy/</source>
        <translation>https://www.deepin.org/zh/agreement/privacy/</translation>
    </message>
    <message>
        <location filename="../src/grand-search/gui/searchconfig/planwidget.cpp" line="78"/>
        <source>).</source>
        <translation>）。</translation>
    </message>
</context>
<context>
    <name>GrandSearch::ScopeWidget</name>
    <message>
        <location filename="../src/grand-search/gui/searchconfig/scopewidget.cpp" line="44"/>
        <source>Search contents</source>
        <translation>搜尋範圍</translation>
    </message>
</context>
<context>
    <name>GrandSearch::SearchEngineWidget</name>
    <message>
        <location filename="../src/grand-search/gui/searchconfig/searchenginewidget.cpp" line="48"/>
        <source>Default search engine</source>
        <translation>預設搜尋引擎</translation>
    </message>
    <message>
        <location filename="../src/grand-search/gui/searchconfig/searchenginewidget.cpp" line="56"/>
        <source>Search for keywords by the default search engine.</source>
        <translation>透過搜尋關鍵字，可跳轉到的預設搜尋引擎</translation>
    </message>
    <message>
        <location filename="../src/grand-search/gui/searchconfig/searchenginewidget.cpp" line="72"/>
        <source>Default search engine is</source>
        <translation>預設搜尋引擎為</translation>
    </message>
    <message>
        <location filename="../src/grand-search/gui/searchconfig/searchenginewidget.cpp" line="81"/>
        <source>Google</source>
        <translation>Google</translation>
    </message>
    <message>
        <location filename="../src/grand-search/gui/searchconfig/searchenginewidget.cpp" line="82"/>
        <source>Baidu</source>
        <translation>百度</translation>
    </message>
    <message>
        <location filename="../src/grand-search/gui/searchconfig/searchenginewidget.cpp" line="83"/>
        <source>Bing</source>
        <translation>必應</translation>
    </message>
    <message>
        <location filename="../src/grand-search/gui/searchconfig/searchenginewidget.cpp" line="84"/>
        <source>Yahoo</source>
        <translation>雅虎</translation>
    </message>
    <message>
        <location filename="../src/grand-search/gui/searchconfig/searchenginewidget.cpp" line="85"/>
        <source>360</source>
        <translation>360</translation>
    </message>
    <message>
        <location filename="../src/grand-search/gui/searchconfig/searchenginewidget.cpp" line="86"/>
        <source>Sogou</source>
        <translation>搜狗</translation>
    </message>
</context>
<context>
    <name>GrandSearch::StaticTextWorker</name>
    <message>
        <location filename="../src/libgrand-search-daemon/searcher/web/statictextworker.cpp" line="69"/>
        <source>Search for &quot;%1&quot;</source>
        <translation>透過瀏覽器搜尋“%1”</translation>
    </message>
</context>
<context>
    <name>GrandSearch::TailerWidget</name>
    <message>
        <location filename="../src/grand-search/gui/searchconfig/tailerwidget.cpp" line="34"/>
        <source>Tailer settings</source>
        <translation>拖尾設定</translation>
    </message>
    <message>
        <location filename="../src/grand-search/gui/searchconfig/tailerwidget.cpp" line="44"/>
        <source>It is displayed at the end of search results for better identification and distinction of items with duplicate names.</source>
        <translation>搜尋結果尾部顯示，用於輔助識別搜尋結果或區分重名項。</translation>
    </message>
    <message>
        <location filename="../src/grand-search/gui/searchconfig/tailerwidget.cpp" line="57"/>
        <source>Parent directory</source>
        <translation>上級目錄</translation>
    </message>
    <message>
        <location filename="../src/grand-search/gui/searchconfig/tailerwidget.cpp" line="59"/>
        <source>Time modified</source>
        <translation>最近修改時間</translation>
    </message>
</context>
<context>
    <name>GrandSearch::audio_preview::AudioPreviewPlugin</name>
    <message>
        <location filename="../src/preview-plugin/audio-preview/audiopreviewplugin.cpp" line="73"/>
        <source>Artist:</source>
        <translation>歌手：</translation>
    </message>
    <message>
        <location filename="../src/preview-plugin/audio-preview/audiopreviewplugin.cpp" line="85"/>
        <source>Album:</source>
        <translation>專輯：</translation>
    </message>
    <message>
        <location filename="../src/preview-plugin/audio-preview/audiopreviewplugin.cpp" line="110"/>
        <source>Duration:</source>
        <translation>時長：</translation>
    </message>
    <message>
        <location filename="../src/preview-plugin/audio-preview/audiopreviewplugin.cpp" line="125"/>
        <source>Type:</source>
        <translation>類型：</translation>
    </message>
    <message>
        <location filename="../src/preview-plugin/audio-preview/audiopreviewplugin.cpp" line="137"/>
        <source>Location:</source>
        <translation>位置：</translation>
    </message>
    <message>
        <location filename="../src/preview-plugin/audio-preview/audiopreviewplugin.cpp" line="151"/>
        <source>Time modified:</source>
        <translation>修改時間：</translation>
    </message>
</context>
<context>
    <name>GrandSearch::image_preview::ImagePreviewPlugin</name>
    <message>
        <location filename="../src/preview-plugin/image-preview/imagepreviewplugin.cpp" line="69"/>
        <source>Dimensions:</source>
        <translation>尺寸：</translation>
    </message>
    <message>
        <location filename="../src/preview-plugin/image-preview/imagepreviewplugin.cpp" line="85"/>
        <source>Type:</source>
        <translation>類型：</translation>
    </message>
    <message>
        <location filename="../src/preview-plugin/image-preview/imagepreviewplugin.cpp" line="100"/>
        <source>Size:</source>
        <translation>大小：</translation>
    </message>
    <message>
        <location filename="../src/preview-plugin/image-preview/imagepreviewplugin.cpp" line="112"/>
        <source>Location:</source>
        <translation>位置：</translation>
    </message>
    <message>
        <location filename="../src/preview-plugin/image-preview/imagepreviewplugin.cpp" line="126"/>
        <source>Time modified:</source>
        <translation>修改時間：</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <location filename="../src/grand-search/gui/datadefine.h" line="39"/>
        <source>Best match</source>
        <translation>最佳匹配</translation>
    </message>
    <message>
        <location filename="../src/grand-search/gui/datadefine.h" line="40"/>
        <source>Applications</source>
        <translation>應用</translation>
    </message>
    <message>
        <location filename="../src/grand-search/gui/datadefine.h" line="41"/>
        <source>Settings</source>
        <translation>設定</translation>
    </message>
    <message>
        <location filename="../src/grand-search/gui/datadefine.h" line="42"/>
        <source>Videos</source>
        <translation>影片</translation>
    </message>
    <message>
        <location filename="../src/grand-search/gui/datadefine.h" line="43"/>
        <source>Music</source>
        <translation>音樂</translation>
    </message>
    <message>
        <location filename="../src/grand-search/gui/datadefine.h" line="44"/>
        <source>Pictures</source>
        <translation>圖片</translation>
    </message>
    <message>
        <location filename="../src/grand-search/gui/datadefine.h" line="45"/>
        <source>Documents</source>
        <translation>文件</translation>
    </message>
    <message>
        <location filename="../src/grand-search/gui/datadefine.h" line="46"/>
        <source>Folders</source>
        <translation>資料夾</translation>
    </message>
    <message>
        <location filename="../src/grand-search/gui/datadefine.h" line="47"/>
        <source>Files</source>
        <translation>文件</translation>
    </message>
    <message>
        <location filename="../src/grand-search/gui/datadefine.h" line="48"/>
        <source>Web</source>
        <translation>Web搜尋</translation>
    </message>
    <message>
        <location filename="../src/preview-plugin/video-preview/videopreviewplugin.cpp" line="42"/>
        <source>Dimensions:</source>
        <translation>尺寸：</translation>
    </message>
    <message>
        <location filename="../src/preview-plugin/video-preview/videopreviewplugin.cpp" line="43"/>
        <source>Type:</source>
        <translation>類型：</translation>
    </message>
    <message>
        <location filename="../src/preview-plugin/video-preview/videopreviewplugin.cpp" line="44"/>
        <source>Size:</source>
        <translation>大小：</translation>
    </message>
    <message>
        <location filename="../src/preview-plugin/video-preview/videopreviewplugin.cpp" line="45"/>
        <source>Duration:</source>
        <translation>影片長度：</translation>
    </message>
    <message>
        <location filename="../src/preview-plugin/video-preview/videopreviewplugin.cpp" line="46"/>
        <source>Location:</source>
        <translation>位置：</translation>
    </message>
    <message>
        <location filename="../src/preview-plugin/video-preview/videopreviewplugin.cpp" line="47"/>
        <source>Time modified:</source>
        <translation>修改時間：</translation>
    </message>
    <message>
        <location filename="../src/libgrand-search-daemon/searcher/file/filesearchutils.cpp" line="220"/>
        <source>modified</source>
        <translation>修改</translation>
    </message>
</context>
</TS>
